#[non_exhaustive]pub struct Rung {
pub height: u32,
pub bitrate: u64,
}Expand description
One candidate output rendition: a target resolution (by height) and bitrate.
The width is derived from the source aspect ratio at runtime, and a rung is
only offered when it is strictly below the source (see Config::rungs).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.height: u32Output height in pixels. Rounded down to even (I420 chroma is 2x2).
bitrate: u64Target bitrate in bits per second: the CBR target and the bitrate advertised in the derivative catalog.
Implementations