Validated output renditions in ascending bitrate and height order.
Structs
- Ladder
- The output ladder, in canonical order: strictly ascending maximum bitrate, and strictly ascending height with it.
- Rung
- One candidate output rendition: a target resolution (by height) and bitrate.
Enums
- Error
- Why a set of rungs is not a ladder.